﻿using System.Collections.Generic;

namespace Bridge
{
    abstract class Lens
    {
        const int min_focuslevel=1;
        const int max_focuslevel=3;
        public int FocusLevel
        {
            get;
            private set;
        }
        public int ModuleIndex
        {
            get;
            private set;
        }
        List<IImageProcessing> modules = new List<IImageProcessing>();
        public int ModuleCount
        {
            get
            {
                return modules.Count;
            }
        }
        public Lens()
        {
            FocusLevel = min_focuslevel;
            ModuleIndex = -1;
        }
        public abstract string Take(string subject, int distance);
        public virtual void FocusUp()
        {
            if (FocusLevel < max_focuslevel)
            {
                FocusLevel++;
            }
        }
        public virtual void FocusDown()
        {
            if (FocusLevel > min_focuslevel)
            {
                FocusLevel--;
            }
        }
        public void AddModule(IImageProcessing module)
        {
            modules.Add(module);
        }    
        protected string ImageProcessing(string subject,int index)
        {
            if((index>=0)||(index<ModuleCount))
            {
                IImageProcessing module = modules[index];
                subject = module.ImageProcessing(subject);
            }			
            return subject;
        }
        protected string MakePicture(string subject,int distance)
        {            
            string s = distance.ToString();            
            return subject.Replace(s,"선명");
        }
        public void SetModuleIndex(int index)
        {
            if((index >=0 )&&(index<ModuleCount))
            {
                ModuleIndex = index;
            }
        }

    }
}
